from extras.plugins import PluginConfig

class NetBoxGrassConfig(PluginConfig):
    name = 'netbox_grass'
    verbose_name = ' NetBox Grass'
    description = 'Back up Configuration of Network Devices in NetBox'
    version = '0.1'
    base_url = 'grass'

config = NetBoxGrassConfig


from setuptools import find_packages, setup

setup(
    name='netbox-grass',
    version='0.1.1',
    description='NetBox plugin that backs up the configuration of network devices.',
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)